from typing import Any, Dict

import os.path
import jinja2
import netaddr

from bottle import request

from matemat import __version__
from matemat.util.currency_format import format_chf
from matemat.webserver.template import Notification
from matemat.webserver.config import get_app_config


__jinja_env: jinja2.Environment = None


def init(config: Dict[str, Any]) -> None:
    global __jinja_env
    themepath = os.path.abspath(os.path.join(config['themeroot'], config['theme'], 'templates'))
    __jinja_env = jinja2.Environment(
        loader=jinja2.FileSystemLoader([themepath, os.path.abspath(config['templateroot'])]),
        autoescape=jinja2.select_autoescape(default=True),
    )
    __jinja_env.filters['chf'] = format_chf


def render(name: str, **kwargs):
    global __jinja_env
    config = get_app_config()
    template: jinja2.Template = __jinja_env.get_template(name)
    wsacl = netaddr.IPSet([addr.strip() for addr in config.get('EanWebsocketAcl', '').split(',')])
    if config.get('EanWebsocketUrl', '') and request.remote_addr in wsacl:
        eanwebsocket = config.get('EanWebsocketUrl')
    else:
        eanwebsocket = None
    return template.render(
        __version__=__version__,
        notifications=Notification.render(),
        eanwebsocket=eanwebsocket,
        **kwargs
    ).encode('utf-8')
